summaryrefslogtreecommitdiffstats
path: root/src/kvirc/ui/kvi_topicw.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/kvirc/ui/kvi_topicw.cpp')
-rw-r--r--src/kvirc/ui/kvi_topicw.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/kvirc/ui/kvi_topicw.cpp b/src/kvirc/ui/kvi_topicw.cpp
index d4a3ecd2..fe9011e1 100644
--- a/src/kvirc/ui/kvi_topicw.cpp
+++ b/src/kvirc/ui/kvi_topicw.cpp
@@ -553,7 +553,7 @@ TQSize KviTopicWidget::tqsizeHint() const
void KviTopicWidget::mouseDoubleClickEvent(TQMouseEvent *)
{
int maxlen=-1;
- TQObject * w = tqparent();
+ TQObject * w = parent();
TQString szModes;
bool bCanEdit = TRUE;
while(w)
@@ -568,7 +568,7 @@ void KviTopicWidget::mouseDoubleClickEvent(TQMouseEvent *)
}
break;
}
- w = w->tqparent();
+ w = w->parent();
}
if(m_pInput == 0)
{
@@ -728,9 +728,9 @@ void KviTopicWidget::deactivate()
m_pDiscard = 0;
}
- // try to find a KviWindow tqparent and give it the focus
+ // try to find a KviWindow parent and give it the focus
- TQObject * w = tqparent();
+ TQObject * w = parent();
while(w)
{
if(w->inherits("KviWindow"))
@@ -738,11 +738,11 @@ void KviTopicWidget::deactivate()
((KviWindow *)w)->setFocus();
return;
}
- w = w->tqparent();
+ w = w->parent();
}
// no KviWindow on the path
- w = tqparent();
+ w = parent();
if(w)
{
if(w->inherits(TQWIDGET_OBJECT_NAME_STRING))